@@ -2,7 +2,7 @@
 #
 # dbginfo.sh - Tool to collect runtime, configuration, and trace information
 #
-# Copyright IBM Corp. 2002, 2024
+# Copyright IBM Corp. 2002, 2025
 #
 # s390-tools is free software; you can redistribute it and/or modify
 # it under the terms of the MIT license. See LICENSE for details.
@@ -38,6 +38,8 @@ readonly LOG_FILE_SIZE_CHECK=50  # max logfile size in MB
 readonly LOG_FILE_AGE_CHECK=7  # age in days to include for size checking
 # Mount point of the debug file system
 readonly MOUNT_POINT_DEBUGFS="/sys/kernel/debug"
+# Network devices
+readonly NETWORK_DEVS=$(cd /sys/class/net; ls -d */ 2>/dev/null |  sed 's/\///g')
 # distro info
 readonly OSPRETTY="$(cat /etc/os* 2>/dev/null | grep -m1 PRETTY_NAME | sed 's/\"//g')"
 readonly OS_NAME="${OSPRETTY##*=}"
@@ -80,8 +82,8 @@ paramWORKDIR_BASE="/tmp"  # initial default path
 # print dbginfo.sh version info
 print_version() {
 	cat <<EOF
-${SCRIPTNAME}: Debug information script version 2.34.0-build-20240827
-Copyright IBM Corp. 2002, 2024
+${SCRIPTNAME}: Debug information script version 2.37.0-build-20250217
+Copyright IBM Corp. 2002, 2025
 EOF
 }
 
@@ -117,8 +119,6 @@ Options:
         -v|--version       print version information
         -c|--check         online base system information (no data collection)
 
-Please report bugs to: linux390@de.ibm.com
-
 EOF
 }
 
@@ -328,6 +328,8 @@ PROCFILES="\
   /proc/mounts\
   /proc/net/vlan\
   /proc/net/bonding\
+  /proc/net/sockstat\
+  /proc/net/sockstat6\
   /proc/net/softnet_stat\
   /proc/partitions\
   /proc/qeth\
@@ -372,6 +374,7 @@ LOGFILES="\
   /var/log/dracut.log*\
   /var/log/IBMtape.trace\
   /var/log/IBMtape.errorlog\
+  /var/log/kdump.log\
   /var/log/libvirt\
   /var/log/lin_tape.trace\
   /var/log/lin_tape.errorlog\
@@ -469,9 +472,11 @@ CONFIGFILES="\
 CMDS="uname -a\
   :uptime\
   :timedatectl\
+  :zhypinfo\
   :last\
   :lscpu -ae\
   :lscpu -ye\
+  :lscpumf -i\
   :lsmem\
   :lsmod\
   :lsshut\
@@ -505,6 +510,7 @@ CMDS="${CMDS}\
 # block device and other scsi device commands (in non alphabetical order)
 #   command groups itself have an intentional topical grouping and order
 CMDS="${CMDS}\
+  :lsblk\
   :lsdasd\
   :lsdasd -u\
   :lvdisplay\
@@ -538,6 +544,8 @@ CMDS="${CMDS}\
 
 # crypto specific commands
 CMDS="${CMDS}\
+  :cpacfinfo # for MSA 13 info\
+  :cpacfinfo -m -f -a -n\
   :ep11info -D\
   :ep11info -H\
   :ep11info -M\
@@ -601,7 +609,8 @@ NETWORK_CMDS="ip -br a\
   :netstat -s\
   :nm-tool\
   :nstat -az\
-  :openssl engine\
+  :openssl engine # deprecated in OpenSSL 3.n\
+  :openssl list --providers 2>/dev/null # redirect help on older systems\
   :route -n\
   "
 
@@ -1009,20 +1018,20 @@ collect_initrd_configfiles() {
 
 ########################################
 collect_osaoat() {
-	local network_devices
-	local network_device
+	local osa_devices
+	local osa_device
 
-	network_devices=$(lsqeth 2>/dev/null | grep "Device name" \
-		     | sed 's/D.*:[[:space:]]*\([^[:space:]]*\)[[:space:]]\+/\1/g' \
-		     | sed 's/[()]//g' )
 	if type qethqoat >/dev/null; then
-		if test -n "${network_devices}"; then
+		osa_devices=$(lsqeth 2>/dev/null | grep "Device name" \
+			     | sed 's/D.*:[[:space:]]*\([^[:space:]]*\)[[:space:]]\+/\1/g' \
+			     | sed 's/[()]//g' )
+		if test -n "${osa_devices}"; then
 			pr_collect_output "osa oat"
-			for network_device in ${network_devices}; do
-				call_run_command "qethqoat ${network_device}" \
+			for osa_device in ${osa_devices}; do
+				call_run_command "qethqoat ${osa_device}" \
 					"${OUTPUT_FILE_OSAOAT}.out" &&
-				call_run_command "qethqoat -r ${network_device}" \
-					"${OUTPUT_FILE_OSAOAT}_${network_device}.raw"
+				call_run_command "qethqoat -r ${osa_device}" \
+					"${OUTPUT_FILE_OSAOAT}_${osa_device}.raw"
 			done
 		else
 			pr_skip "osa oat: no devices"
@@ -1034,14 +1043,12 @@ collect_osaoat() {
 
 ########################################
 collect_ethtool() {
-	local network_devices
 	local network_device
 
-	network_devices=$(ls /sys/class/net 2>/dev/null)
 	if type ethtool >/dev/null; then
-		if test -n "${network_devices}"; then
+		if test -n "${NETWORK_DEVS}"; then
 			pr_collect_output "ethtool"
-			for network_device in ${network_devices}; do
+			for network_device in ${NETWORK_DEVS}; do
 				call_run_command "ethtool ${network_device}" \
 					"${OUTPUT_FILE_ETHTOOL}"
 				call_run_command "ethtool -k ${network_device}" \
@@ -1077,14 +1084,12 @@ collect_ethtool() {
 
 ########################################
 collect_tc() {
-	local network_devices
 	local network_device
 
-	network_devices=$(ls /sys/class/net 2>/dev/null)
 	if type tc >/dev/null; then
-		if test -n "${network_devices}"; then
+		if test -n "${NETWORK_DEVS}"; then
 			pr_collect_output "Trafic Control"
-			for network_device in ${network_devices}; do
+			for network_device in ${NETWORK_DEVS}; do
 				call_run_command "tc -s qdisc show dev ${network_device}" \
 					"${OUTPUT_FILE_TC}"
 			done
@@ -1098,14 +1103,12 @@ collect_tc() {
 
 ########################################
 collect_bridge() {
-	local network_devices
 	local network_device
 
-	network_devices=$(ls /sys/class/net 2>/dev/null)
 	if type bridge >/dev/null; then
-		if test -n "${network_devices}"; then
+		if test -n "${NETWORK_DEVS}"; then
 			pr_collect_output "bridge"
-			for network_device in ${network_devices}; do
+			for network_device in ${NETWORK_DEVS}; do
 				call_run_command "bridge -d link show dev ${network_device}" \
 					"${OUTPUT_FILE_BRIDGE}"
 				call_run_command "bridge -s fdb show dev ${network_device}" \
